@@ -1,4 +1,4 @@
-from typing import ClassVar, Generic, List, Optional, TypeVar, Union
+from typing import Any, ClassVar, Generic, List, Optional, TypeVar, Union
 
 from pydantic import BaseModel, BaseSettings, Field, create_model, validator
 from pydantic.dataclasses import dataclass
@@ -224,3 +224,41 @@ class FieldDefaultTestingModel(BaseModel):
     g: List[int] = Field(default_factory=_default_factory_list)
     h: str = Field(default_factory=_default_factory_str)
     i: str = Field(default_factory=lambda: 'test')
+
+
+# Include the import down here to reduce the effect on line numbers
+from dataclasses import InitVar  # noqa E402
+
+
+@dataclass
+class MyDataClass:
+    foo: InitVar[str]
+    bar: str
+
+
+MyDataClass(foo='foo', bar='bar')
+
+
+_TModel = TypeVar('_TModel')
+_TType = TypeVar('_TType')
+
+
+class OrmMixin(Generic[_TModel, _TType]):
+    @classmethod
+    def from_orm(cls, model: _TModel) -> _TType:
+        raise NotImplementedError
+
+    @classmethod
+    def from_orm_optional(cls, model: Optional[_TModel]) -> Optional[_TType]:
+        if model is None:
+            return None
+        return cls.from_orm(model)
+
+
+class Sample(BaseModel):
+    foo: str
+    bar: Optional[str] = Field(description='optional')
+    zoo: Any
+
+
+Sample(foo='hello world')
